+++
title = "Machine dynamics in mechatronic systems: an engineering approach."
author = ["Thomas Dehaeze"]
draft = false
+++

Tags
: [Finite Element Model]({{<relref "finite_element_model.md#" >}})

Reference
: ([Rankers 1998](#org6436602))

Author(s)
: Rankers, A. M.

Year
: 1998


## Summary {#summary}

<summary>
Despite the fact, that mechanical vibrations in a servo device can be very complex and often involve the motion of many components of the system, there are three fundamental mechanisms that are often observed.
These there basic dynamic phenomena can be indicated by:

-   **Actuator flexibility**: the mechanical system does not behave as one rigid body, due to flexibility between the location at which the servo force is applied and the actual point that needs to be positioned
-   **Guiding system flexibility**: the device usually rely on the guiding system to suppress motion in an undesired direction
-   **Limited mass and stiffness of the stationary machine part**: the reaction force that comes with the driving force will introduce a motion of the "stationary" part of the mechanical system

Whereas the first two phenomena mainly affect the stability of the control loop, the last phenomena manifests itself more often as a dynamic positional error in the set-point response.

A tool that can be very useful in understanding the nature of more complex resonance phenomena and the underlying motion of the mechanical system, is **Modal Analysis**.
Translating the mathematics of one single decoupled "modal" equation into a graphical representation, which includes all relevant data such as (effective) modal mass and stiffness plus the motion of each physical DoF, facilitates a better understanding of the modal concept.
It enables a very intuitive link between the modal and the physical domain, and thus leads to a more creative use of "modal analysis" without the complications of the mathematical formalism.

Dynamic phenomena of the mechanics in a servo positioning device can lead to stability problems of the control loop.
Therefore it is important to investigate the frequency response (\\(x/F\\)), which characterizes the dynamics of the mechanical system, and especially the influence of mechanical resonances on it.
Once the behavior of one individual mode is fully understood it is not so difficult to construct this frequency response and the interaction between the rigid-body motion of the device, and the dynamics of one additional mode.
This leads to **four interaction patterns**:

-   -2 slope / zero / pole / -2 slope
-   -2 slope / pole / zero / -2 slope
-   -2 slope / pole / -4 slope
-   -2 slope / pole / -2 slope (non-minimum phase and rarely occurring)

It is not possible to judge the potential destabilizing effect of each of the typical characteristics without considering the frequency of the resonance in relation to the envisaged bandwidth of the control loop.
The phase plot of a typical open loop frequency response of a PID controlled positioning device without mechanical resonances can be divided into three frequency ranges (supposing the plant model is just a mass line):

-   at low frequencies, the phase lies below -180 deg due to integrator action of the controller
-   at medium frequency (centered by the bandwidth frequency), the phase lies above -180 deg due to the differential action of the controller, which is necessary in order to achieve a stable position control-loop
-   at high frequencies, the phase eventually drops again below -180 deg due to additional low-pass filtering

The potential **destabilizing effect** of each of the three typical characteristics can be judged in relation to the frequency range:

-   A -2 slope / zero / pole / -2 slope characteristics leads to a phase lead and is therefore potentially destabilizing in the low-frequency and high frequency regions.
    In the medium frequency region it adds an extra phase leads to the already existing margin, which does not harm the stability.
-   A -2 slope / pole / zero / -2 slope combination has the reverse effect.
    It is potentially destabilizing in the medium-frequency range and is harmless in the low and high frequency ranges.
-   The -2 slope / poles / -4 slope behavior always has a devastating effect on the stability of the loop if located in the low or medium frequency range.

Whether instability occurs depends very strongly on the resonance amplitude and damping of the additional mode.
On the basis of these considerations, it is possible to give design guidelines for servo positioning devices.

The subject of machine dynamics and its interaction with the control system plays a dominant role in fast and accurate positioning devices, so it is vital to consider these issues during the entire design process.
**Modeling and simulation** can be adequate tools for that purpose; however, two conditions are crucial to the success:

-   usefulness of results
-   speed

The analysis process has usually a **top-down structure**.
Starting with very elementary simulation models to support the selection of the proper concept, these models should become more refined, just like the product or machine under development.

In various project throughout the past years, a **three-step modeling approach** has evolved, in which the following phases can be distinguished:

-   concept analysis
-   system analysis
-   component analysis

In the **concept analysis** the viability of various concepts is evaluated on the basis of very simple models consisting of a limited number of lumped masses connected by springs.
Once a concept has been chosen and the first rough 3D sketches become available, a **system analysis** can be done, based on a limited number of 3D rigid components connected by springs.
In this phase a lot of important spatial information is added to the model (such as the location of the center of gravity and connecting stiffnesses, plus the location of the driving force and of the sensors).
Finally, in the **component analysis** phase, critical components are no longer considered rigid, and their internal dynamics are evaluated via Finite Element (FE) modeling.
In cases in which a separate analysis of a critical component is considered insufficient to judge its influence on the overall dynamics, a detailed FE-based description can be used to replace the former rigid description in the system model.

In case many parts of the system need to be modeled in great detail, it is not very practical (error-prone, huge model size, time consuming) to build on, single, huge FE model of the entire system.
A technique that overcomes these disadvantages is the so-called "**sub-structuring technique**".
In this approach the system is divided into substructures or components, which are analyzed separately.
Then, after application of a reduction technique which preserves the most dominant dynamic properties, the (reduced) models of the components are assemble to form the overall system.
By doing so, the size of the final system model is reduced significantly.
</summary>


## Introduction {#introduction}


### General {#general}

In the development of servo-controlled positioning devices, it is essential to consider the effect of the dynamics of the mechanical system on the performance of the overall, because the following effects can be observed:

-   mechanical resonances can endanger the stability of the control loop
-   vibration of the mechanical system, which are cause by the servo forces during a prescribed motion, can lead to positional errors

To obtain a well-balanced design with respect to the effort in the mechanical design and the control design, one has to adapt a mechatronics approach in which the structural design and the control design are integrated.
Integrated modelling and simulation of structural and control aspects should be part of the product-creation process of any mechatronic positioning device from the very beginning.
Such an approach is the only way the enhance the score of success and achieve "first-time-right".


### State of the Art {#state-of-the-art}

In general, the modelling of certain phenomena that take place in a machine can be divided into two major steps:

1.  From reality/design to a physical model
2.  From the physical model to a mathematical model

In the first step, the real structure of design drawing of a structure needs to be translated into a physical model, which is a simplification of the reality that contains all relations considered to be important to describe the phenomenon.
Once this physical model has been derived, the second step consists of translating this physical model into a mathematical model which is usually straightforward using adapted software.

The following questions are only seldom addressed:

-   which analysis must be carried out
-   how should the results be interpreted
-   what sort of physical model gives a reasonable balance between accuracy and required effort

There is a huge gap between available theory about modal analysis and engineering practice which is also true for the field of control theory.
The integration of machine dynamics and control system design is also limited as the two topics are generally taught by different departments.
Machine dynamics is an issue addressed by the mechanical engineer, whereas the control system is designed by the electrical engineer.

<div class="important">
  <div></div>

The lack of integral knowledge of machine dynamics, control and the interaction between these two topics is a serious threshold in finding the optimal solution to a mechatronic design problem.

</div>


### Scope and Purpose {#scope-and-purpose}

This thesis aims at bridging the gap between existing theoretical knowledge in the field of machine dynamics and control, and the practical application of this knowledge during the design of a product or machine.

The idea is to show that a basic understanding of machine dynamics suffices to interpret complex mechanical vibrations.
Moreover, in combination with basic control theory it is possible to derive the typical patterns that can be observed in an open-loop frequency response of a mechanical servo-system including resonances, and to draw conclusions with respect to the effect of these resonances on the stability of the control loop.
Based on the idea that the controlled system must satisfy certain disturbance rejection and bandwidth criteria, design guidelines can be given for the mechanical system such that the chance of realizing the required bandwidth without introduction stability problems is maximized.
By using a step-wise modelling approach it is possible to investigate and **predict these phenomena during the design phase**, and to make design decisions which take the dynamics and control aspects into account.


### Preview {#preview}

<div class="question">
  <div></div>

The basic questions that are addressed in this thesis are:

-   What sort of dynamic effects are important in mechatronic devices?
-   How can the dynamics of a complex system be described and understood?
-   What is the influence of mechanical resonances on the stability of a control loop?
-   Which design rules can be given to minimize the destabilizing effect of machine dynamics?
-   How can one predict the machine dynamics in an industrial way, such that simulation and modelling is experienced as an effective design tool?

</div>


## Mechanical Servo Systems {#mechanical-servo-systems}


### Basic Control Aspects {#basic-control-aspects}

A block diagram representation of a typical servo-system is shown in Figure [1](#orga7794da).
The main task of the system is achieve a desired positional relation between two or more components of the system.
Therefore, a sensor measures the position which is then compared to the desired value, and the resulting error is used to generate correcting forces.
In most systems, the "actual output" (e.g. position of end-effector) cannot be measured directly, and the feedback will therefore be based on a "measured output" (e.g. encoder signal at the motor).
It is important to realize that these two outputs can differ, first due to resilience in the mechanical system, and second because of geometrical imperfections in the mechanical transmission between motor and end-effector.

<a id="orga7794da"></a>

{{< figure src="/ox-hugo/rankers98_basic_el_mech_servo.png" caption="Figure 1: Basic elements of mechanical servo system" >}}

The basic ingredient of most feedback control-systems is a PID controller, which is a combination of a proportional gain \\(P\\), and integral control \\(I\\) to enhance steady state behavior, and a derivative action \\(D\\) to improve damping and stability.
The correction force \\(F\\) is defined by:

\begin{equation}
F = k\_p \epsilon + k\_d \dot{\epsilon} + k\_i \int \epsilon dt
\end{equation}

It is illustrative to see that basically the proportional and derivative part of such a position control loop is very similar to a mechanical spring and damper that connect two points (Figure [2](#org3f53580)).
If \\(c\\) and \\(d\\) represent the constant mechanical stiffness and damping between points \\(A\\) and \\(B\\), and a reference position profile \\(h(t)\\) is applied at \\(A\\), then an opposing force \\(F\\) is generated as soon as the position \\(x\\) and speed \\(\dot{x}\\) of point \\(B\\) does not correspond to \\(h(t)\\) and \\(\dot{h}(t)\\).

<a id="org3f53580"></a>

{{< figure src="/ox-hugo/rankers98_basic_elastic_struct.png" caption="Figure 2: Basic Elastic Structure" >}}

The resulting spring/damper force is equal to:

\begin{equation}
F = c (h(t) - x) + d(\dot{h}(t) - \dot{x})
\end{equation}

Thus, in this example a PD position-control loop can be treated in the same way as a mechanical system with a spring \\(c = k\_p\\) and damper \\(d = k\_d\\).
The most important difference is the fact that a mechanical spring/damper is a _passive_ element, whereas firstly a control loop is an _active_ element, and secondly the servo forces that are applied between points \\(A\\) and \\(B\\) can be based on a measurement at a different location.
These properties are very essential since they introduce the issue of **servo stability**, which can be seriously endangered by mechanical resonances.

An important aspect of a feedback controller is the fact that control forces can only result from an error signal.
Thus any desired set-point profile first leads to a position error before the corresponding driving forces are generated.
Most modern servo-systems have not only a feedback section, but also a **feedforward** section, as indicated in Figure [3](#org4a1de51).

<a id="org4a1de51"></a>

{{< figure src="/ox-hugo/rankers98_feedforward_example.png" caption="Figure 3: Mechanical servo system with feedback and feedforward control" >}}

In the feedforward section, control signals are derived from the desired output (position, speed and acceleration) using a model of the mechanical servo-system.
In practice, a feedforward section gives a significant performance improvement in case of point-to-point and tacking applications, but a feedback section will always be necessary.
First, because the model used in the calculation of the feedforward signal is not a perfect representation of the actual system and second because of the presence of unknown disturbances.

Practicing engineers generally accomplish the feedback design and analysis on the basis of the frequency response.
One of the major benefits of this approach is the close link to experimental information that can be obtained by exciting the system with sinusoidal inputs and varying frequency and measuring the amplitude and phase of the output.
Such frequency response can either be plotted using a Bode diagram of a Nyquist diagram.

An engineering approach to stability evaluation is the so-called "Left Hand Rule", which reads:

> If a system contains only stable elements in the open loop, then the closed loop system is stable if the point \\((-1,0)\\) in the Nyquist diagram lies on the left hand side of the open loop response when it is run through in the direction of increasing frequency.

In order to quantify the level of stability, two criteria have been introduced: gain and phase margin which measure how close the open loop response approaches the point \\((-1,0)\\) in the Nyquist diagram.


### Specifications {#specifications}

Specification of a feedback controller is very closely linked to disturbance rejection, especially in modern controllers that incorporate a feedforward section.
The required performance of the feedback section, which is generally expressed in terms of bandwidth, depends very much on the disturbances that act on the system.

These disturbances can be very different, and vary from application to application:

-   Random floor vibration
-   Imperfections of the guiding systems
-   Harmonic excitation forces due to the presence of pumps or ventilators
-   Acoustic excitation


### Interaction Dynamics and Control {#interaction-dynamics-and-control}

Basically, machine dynamics can have two deterioration effects in mechanical servo systems:

-   Mechanical resonances can endanger servo stability, and thus limit the bandwidth and the amount of disturbance rejection.
-   Vibrations can lead to positional errors at the end of a set-point motion, or during a tracking motion.


### Three Important Dynamic Effects {#three-important-dynamic-effects}


#### Actuator Flexibility {#actuator-flexibility}

The basic characteristics of what is called "actuator flexibility" is the fact that in the frequency range of interest (usually \\(0-10\times \text{bandwidth}\\)) the driven system no longer behaves as one rigid body (Figure [4](#orgd374c3a)) due to compliance between the motor and the load.

<a id="orgd374c3a"></a>

{{< figure src="/ox-hugo/rankers98_actuator_flexibility.png" caption="Figure 4: Actuator Flexibility" >}}


#### Guiding System Flexibility {#guiding-system-flexibility}

The second category of dynamic phenomena results from the limited stiffness of the guiding system in combination with the fact the the device is driven in such a way that it has to rely on the guiding system to suppress motion in an undesired direction (in case of a linear direct drive system this occurs if the driving force is not applied at the center of gravity).

In general, a rigid actuator possesses six degrees of freedom, five of which need to be suppressed by the guiding system in order to leave one mobile degree of freedom.
In the present discussion, a planar actuator with three degrees of freedom will be considered (Figure [5](#orgc0e4433)).

<a id="orgc0e4433"></a>

{{< figure src="/ox-hugo/rankers98_guiding_flexibility_planar.png" caption="Figure 5: Planar actuator with guiding system flexibility" >}}

The carriage is free to move in the guiding direction \\(x\\), whereas the perpendicular displacement \\(y\\) and the rotation \\(\phi\\) is prevented via two fixtures with limited stiffness \\(c\\).
The limited support stiffness and the inertia properties of the actuator will result in two resonances, which can be characterized as perpendicular mode and rocking mode.

Every actuator as some sort of guiding system in order to suppress certain DoF, and thus possesses guiding modes.
However, whether this leads to dynamic problems depends very much on the location of the driving force and the sensor.
By choosing the proper location of the driving force one can avoid excitation of these modes, whereas **the location of the sensor influences the effect of such a mode on the servo stability** where excitation of the mode could not be avoided.

In general, it should be attempted to design the actuator (mass distribution and location of driving force) such that it will perform the desired motion even in the absence of the guiding system.


#### Limited Mass and Stiffness of Stationary Machine Part {#limited-mass-and-stiffness-of-stationary-machine-part}

The last category of dynamic phenomena results from the limited mass and stiffness of the stationary part of a mechanical servo-system.
In contrast to many textbooks on mechanics and machine dynamics, it is good practice always to look at the combination of driving force on the moving part, and **reaction force** on the stationary part, of a positioning device.
When doing so, one has to consider what the effect of the reaction force on the systems performance will be.
In the discussion of the previous two dynamic phenomena, the stationary part of the machine was assumed to be infinitely stiff and heavy, and therefore the effect of the reaction force was negligible.
However, in general the stationary part is neither infinitely heavy, nor is it connected to its environment with infinite stiffness, so the stationary part will exhibit a resonance that is excited by the reaction forces (Figure [6](#org22ae9b4)).

<a id="org22ae9b4"></a>

{{< figure src="/ox-hugo/rankers98_limited_m_k_stationary_machine_part.png" caption="Figure 6: Limited Mass and Stiffness of Stationary Machine Part" >}}

Practice has taught that in a well-designed servo system the effect of such a resonance on the stability of the servo system is generally small; even then it can have a significant impact on the set-point response.

The effect of frame vibrations is even worse where the quality of positioning of the servo system is not determined by the position of the actuator relative to the frame, but by the position of the actuator relative to the world (for example a robot that has to pick a component from a pallet that is placed on the floor).


## [Modal Decomposition]({{<relref "modal_decomposition.md#" >}}) {#modal-decomposition--modal-decomposition-dot-md}

To understand and describe the behaviour of a mechanical system in a quantitative way, one usually sets up a model of the system.
The mathematical description of such a model with a finite number of DoF consists of a set of ordinary differential equations.
Although in the case of simple systems, such as illustrated in Figure [7](#orgb3fe7a3) these equations may be very understandable, in the case of complex systems, the set of differential equations itself gives only limited insight, and mainly serves as a basis for numerical simulations.

<a id="orgb3fe7a3"></a>

{{< figure src="/ox-hugo/rankers98_1dof_system.png" caption="Figure 7: Elementary dynamic system" >}}

A very powerful tool, both numerically and experimentally, in understanding the dynamic properties of a mechanical system, is the concept of "**modal analysis**".


### Mathematics of Modal Decomposition {#mathematics-of-modal-decomposition}

The general equation of motion of a linear mechanical system with a finite number of DoF, and without damping is:

\begin{equation}
M \ddot{x}(t) + K x(t) = f(t)
\end{equation}

in which \\(M\\) and \\(K\\) stand for the symmetric semi-positive definite mass and stiffness matrix, \\(x(t)\\) and \\(\ddot{x}(t)\\) represent the displacement and acceleration vectors, and \\(f(t)\\) denotes the vector of forces.

Generally this system of equations is coupled but it can always be decoupled by using a transformation based on the non-trivial solutions (the eigenvectors) of the following eigenvalue problem:

\begin{equation}
(K + \omega\_i^2 M) \phi\_i = 0
\end{equation}

Solving the eigenvalue problem gives the eigenvalues \\(\omega\_1^2, \omega\_2^2, \dots, \omega\_n^2\\) and the corresponding eigenvectors or mode-shape vectors \\(\phi\_1, \phi\_2, \dots, \phi\_n\\).

These eigenvectors have the following orthogonality properties, or can always be chosen such that:

\begin{equation} \label{eq:eigenvector\_orthogonality\_mass}
\phi\_i^T M \phi\_j = 0 \quad (i \neq j)
\end{equation}

For \\(i=j\\) the result of the multiplication according to equation \eqref{eq:eigenvector_orthogonality_mass} yields a non-zero result, which is normally indicated as **modal mass** \\(\mathit{m}\_i\\):

\begin{equation} \label{eq:modal\_mass}
\phi\_i^T M \phi\_i = \mathit{m}\_i
\end{equation}

Because only the direction but not the length of an eigenvector is defined, several scaling methods are used, all based on equation \eqref{eq:modal_mass}:

-   \\(|\phi\_i| = 1\\):: Each eigenvector \\(\phi\_i\\) is scaled such that its length is equal to \\(1\\). The modal mass are then calculated from equation \eqref{eq:modal_mass}.
-   \\(\max(\phi\_i) = 1\\):: Each eigenvector \\(\phi\_i\\) is scaled such that its largest element is equation to \\(1\\). The modal mass is then calculated from equation \eqref{eq:modal_mass}.
-   \\(m\_i = 1\\):: The modal mass \\(\mathit{m}\_i\\) is set to \\(1\\). The scaling of the mode vector \\(\phi\_i\\) follows from equation \eqref{eq:modal_mass}.

The orthogonality properties also apply to the stiffness matrix \\(K\\):

\begin{align}
\phi\_i^T K \phi\_j &= 0 \quad (i \neq j) \\\\\\
\phi\_i^T K \phi\_i &= \omega\_i^2 \mathit{m}\_i = \mathit{k}\_i
\end{align}

Because the \\(n\\) eigenvectors \\(\phi\_i\\) form a **base** in the n-dimensional space, any displacement vector \\(x(t)\\) can be written as a linear combination of the eigenvectors.
Let \\(q\_i(t)\\) be the response of the decoupled mode \\(i\\), then the resulting displacement vector \\(x(t)\\) will be:

\begin{equation}
x(t) = q\_1(t) \phi\_1 + q\_2(t) \phi\_2 + \dots + q\_n(t) \phi\_n
\end{equation}

For one individual physical DoF \\(x\_k\\):

\begin{equation}
x(t) = q\_1(t) \phi\_{1k} + q\_2(t) \phi\_{2k} + \dots + q\_n(t) \phi\_{nk}
\end{equation}

with \\(\phi\_{ik}\\) being the element of the mode-shape vector \\(\phi\_i\\) that corresponds to the physical DoF \\(x\_k\\).

The physical interpretation of the above two equations is that any motion of the system can be regarded as a combination of the contribution of the various modes.

On can combine the eigenvectors in a matrix \\(\Phi\\) and the coefficients \\(q\_i\\) in a vector \\(q(t)\\) which leads to:

\begin{equation}
x(t) = \Phi q(t)
\end{equation}

With:

\begin{align}
 \Phi &= \begin{bmatrix} \phi\_1 & \phi\_2 & \dots & \phi\_n \end{bmatrix} \\\\\\
 q(t) &= \begin{bmatrix} q\_1(t) \\ q\_2(t) \\ \vdots \\ q\_n(t) \end{bmatrix}
\end{align}

Substitution of \\(x(t) = \Phi q(t)\\) into the original equation of motion and premultiplication with \\(\Phi^T\\) results in:

\begin{equation}
\Phi^T M \Phi \ddot{q}(t) + \Phi^T K \Phi q(t) = \Phi^T f(t)
\end{equation}

Which finally leads to a set of **uncoupled** equations of motion that describe the contribution of each mode:

\begin{equation}
\begin{bmatrix}
m\_1 & & & \\\\\\
& m\_2 & & \\\\\\
& & \ddots & \\\\\\
& & & m\_n
\end{bmatrix} \begin{bmatrix}
\ddot{q}\_1 \\ \ddot{q}\_2 \\ \vdots \\ \ddot{q}\_n
\end{bmatrix} + \begin{bmatrix}
k\_1 & & & \\\\\\
& k\_2 & & \\\\\\
& & \ddots & \\\\\\
& & & k\_n
\end{bmatrix} \begin{bmatrix}
q\_1 \\ q\_2 \\ \vdots \\ q\_n
\end{bmatrix} = \begin{bmatrix}
\phi\_1^T f \\ \phi\_2^T f \\ \vdots \\ \phi\_n^T f
\end{bmatrix}
\end{equation}

For the i-th modal coordinate \\(q\_i\\) the equation of motion is:

\begin{equation} \label{eq:eoq\_modal\_i}
m\_i \ddot{q\_i}(t) + k\_i q\_i(t) = \phi\_i^T f(t)
\end{equation}

which is a simple second order differential equation similar to that of a single mass spring system.
Using basic formulae that are derived for a simple mass spring system, one is now able to analyze the time and frequency response of all individual modes.
Having done that, the total motion of the system can simply be obtained by summing the contributions of all modes.

Characterisation of the dynamics of a mechanical system in terms of frequency response behavior plays a major role in the stability analysis of the control loop of a mechatronic device.
In such an analysis one is typically interested in the transfer function between a measured displacement \\(x\_l\\) and a force \\(f\_k\\), which acts at the physical DoF \\(x\_k\\).
Applying the principle of modal decomposition, any transfer function can be derived by first calculating the behavior of the individual modes, and then **summing all modal contributions**.

The contribution of one single mode \\(i\\) to the transfer function \\(x\_l/f\_k\\) can be derived by first considering the response of the modal DoF \\(q\_i\\) to a force vector \\(f\\) with only one non-zero component \\(f\_k\\).
In that case, equation \eqref{eq:eoq_modal_i} is reduced to:

\begin{equation}
m\_i \ddot{q}\_i(t) + k\_i q\_i(t) = \phi\_{ik} f\_k(t)
\end{equation}

After a Laplace transformation and some rearrangement:

\begin{equation}
q\_i(s) = f\_k(s) \frac{\phi\_{ik}}{m\_i s^2 + k\_i}
\end{equation}

Once the modal response \\(q\_i\\) is known, the response of the physical DoF \\(x\_l\\) is found by a simple premultiplication with \\(\phi\_{il}\\), which finally leads to the following expression for the contribution of mode \\(i\\) to the transfer function:

\begin{equation}
\left( \frac{x\_l}{f\_k} \right)\_i = \frac{\phi\_{ik}\phi\_{il}}{m\_i s^2 + k\_i}
\end{equation}

<div class="important">
  <div></div>

The overall transfer function can be found by summation of the individual modal contributions, which all have the same structure:

\begin{equation}
\left( \frac{x\_l}{f\_k} \right) = \sum\_{i = 1}^n \left( \frac{x\_l}{f\_k} \right)\_i = \sum\_{i = 1}^n \frac{\phi\_{ik} \phi\_{il}}{m\_i s^2 + k\_i}
\end{equation}

</div>


### Graphical Representation {#graphical-representation}

Due to the equivalence with the differential equations of a single mass spring system, equation \eqref{eq:eoq_modal_i} is often represented by a single mass spring system on which a force \\(f^\prime = \phi\_i^T f\\) acts.
However, this representation implies an important loss of information because it neglects all information about the mode-shape vector.

Consider the system in Figure [8](#org04e36cc) for which the three mode shapes are depicted in the traditional graphical representation.
In this representation, the physical DoF are located at fixed positions and the mode shapes displacement is indicated by the length of an arrow.

<a id="org04e36cc"></a>

{{< figure src="/ox-hugo/rankers98_mode_trad_representation.png" caption="Figure 8: System and traditional graphical representation of modes" >}}

Alternatively, considering that for each mode the mode shape vector defined a constant relation between the various physical DoF, one could also represent a mode shape by a lever (Figure [9](#org17d6c66)).
For each individual mode \\(i\\), each physical DoF \\(x\_k\\) is indicated on the lever at a position with respect to the point of rotation that corresponds to the amplitude and sign of that DoF in the mode shape vector (\\(\phi\_{ik}\\)).
System with no, very little, or proportional damping exhibit real mode shape vectors, and thus the various DoF each their maximum values at the same moment of the cycle.
Consequently, the respective DoF can only be in phase or in opposite phase.
All DoF on the same side of the rotation point have identical phases, whereas DoF on opposite sides have opposite phases.

The modal DoF \\(q\_i\\) can be interpreted as the displacement at a distance "1" from the pivot point (Figure [9](#org17d6c66)).

<a id="org17d6c66"></a>

{{< figure src="/ox-hugo/rankers98_mode_new_representation.png" caption="Figure 9: System and new graphical representation of mode-shape" >}}

In the case of a lumped mass model, as in the previous example, it is possible to indicate at each physical DoF on the modal lever the corresponding physical mass, as shown in Figure [10](#org0de4b98) (a).
The resulting moment of inertia \\(J\_i\\) of the i-th modal lever then is:

\begin{equation}
J\_i = \sum\_{k=1}^n m\_k \phi\_{ik}^2
\end{equation}

This result is identical to the modal mass \\(m\_i\\) found with Equation \eqref{eq:modal_mass}, because the mass matrix \\(M\\) is a diagonal matrix of physical masses \\(m\_k\\), and consequently the expression for the modal mass \\(m\_i\\) yields:

\begin{equation}
m\_i = \phi\_j^T M \phi\_j = \sum\_{k=1}^n m\_k \phi\_{ik}^2
\end{equation}

As a result of this, the modal mass \\(m\_i\\) could be interpreted as the resulting mass moment of inertia of the modal lever, or alternatively as a mass located at a distance "1" from the pivot point.

The transition from physical masses to modal masses is illustrated in Figure [10](#org0de4b98) for the mode 2 of the example system.
The modal stiffness \\(k\_2\\) is simply calculated via the relation between natural frequency, mass and stiffness:

\begin{equation}
k\_i = \omega\_i^2 m\_i
\end{equation}

<a id="org0de4b98"></a>

{{< figure src="/ox-hugo/rankers98_mode_2_lumped_masses.png" caption="Figure 10: Graphical representation of mode 2 with (a.) lumped masses and (b.) modal mass and stiffness" >}}

Let's now consider the effect of excitation forces that act on the physical DoF.
The scalar product \\(\phi\_{ik}f\_k\\) of each force component with the corresponding element of the mode shape vector can be seen as the moment that acts on the modal level, or as an equivalent force that acts at the location of \\(q\_i\\) on the lever.
Based on the graphical representation in Figure [11](#orgef7eb39), it is not difficult to understand the contribution of mode i to the transfer function \\(x\_l/f\_k\\):

\begin{equation}
\left( \frac{x\_l}{f\_k} \right)\_i = \frac{\phi\_{ik}\phi\_{il}}{m\_i s^2 + k\_i}
\end{equation}

Hence, the force \\(f\_k\\) must be multiplied by the distance \\(\phi\_{ik}\\) in order to find the equivalent excitation force at the location of \\(q\_i\\) on the lever, whereas the resulting modal displacement \\(q\_i\\) must be multiplied by the distance \\(\phi\_{il}\\) in order to obtain the displacement of the physical DoF \\(x\_l\\).

<a id="orgef7eb39"></a>

{{< figure src="/ox-hugo/rankers98_lever_representation_with_force.png" caption="Figure 11: Graphical representation of mode \\(i\\), including the proper location of a force component \\(f\_k\\) that acts on physical DoF \\(x\_k\\)" >}}

Often, one is not directly interested in the response of one single physical DoF, but rather in some linear combination of DoF (for instance the relative position of two DoF).
This linear combination of physical DoF, which will be called "User DoF" can be written as:

\begin{equation}
x\_u = b\_1 x\_1 + \dots + b\_n x\_n = b^T x
\end{equation}

User DoF can be indicated on the modal lever, as illustrated in Figure [12](#orga82e374) for a user DoF \\(x\_u = x\_3 - x\_2\\).
The location of this user DoF \\(x\_u\\) with respect to the pivot point of modal lever \\(i\\) is defined by \\(\phi\_{iu}\\):

\begin{equation}
\phi\_{iu} = b^T \phi\_i
\end{equation}

<a id="orga82e374"></a>

{{< figure src="/ox-hugo/rankers98_representation_user_dof.png" caption="Figure 12: Graphical representation of mode including user DoF \\(x\_u = x\_3 - x\_2\\)" >}}

Even though the dimension mode vector can be very large, only three user DoF are really important for servo-application which define:

-   input (how much a mode is excited by the servo force)
-   measured output (displacement that is measured by the position sensor)
-   actual output (displacement that determines the accuracy of the machine)

To illustrate this, a servo controlled positioning device is shown in Figure [13](#orgae9e430).
The task of the device is to position the payload with respect to a tool that is mounted to the machine frame.
The actual accuracy of the machine is determined by the relative motion of these two components (actual output).
However, direct measurement of the distance between the tool and the payload is not possible and therefore the control action is based on the measured distance between a sensor and the slide on which the payload is mounted (measured output).
The slide is driven by a linear motor which transforms the output of the controller into a force on the slide and a reaction force on the stator (input).

<a id="orgae9e430"></a>

{{< figure src="/ox-hugo/rankers98_servo_system.png" caption="Figure 13: Schematic representation of a servo system" >}}


### Physical Meaning of Modal Parameters {#physical-meaning-of-modal-parameters}

Unfortunately, the mathematical approach of the scaling procedure of mode-shapes and modal parameters sometimes obscures the physical meaning of modal mass and modal stiffness.
The link to the real world can be found bia the **effective modal mass** and the **effective modal stiffness** of a mode as it is "felt" in a certain DoF.
These quantities are unique, do not depend on the scaling procedure and have physical meaning and physical units.

The effective modal parameters of mode \\(i\\) in physical DoF \\(k\\) can be derived from the modal parameters via the following equations:

\begin{align}
m\_{\text{eff},ik} &= m\_i/\phi\_{ik}^2 \label{eq:m\_modal\_eff} \\\\\\
k\_{\text{eff},ik} &= k\_i/\phi\_{ik}^2 \label{eq:k\_modal\_eff}
\end{align}

These effective modal parameters can be used very effectively in understanding topics such as sensitivity analysis or constructing the frequency response of a complex system from knowledge of modal contributions.

<div class="exampl">
  <div></div>

The eigenvalue analysis of the two mass spring system in Figure [14](#orgbf0f71b) leads to the modal results summarized in Table [1](#table--tab:2dof-example-modal-params) and which are graphically represented in Figure [15](#org9a6d0a0).

<a id="orgbf0f71b"></a>

{{< figure src="/ox-hugo/rankers98_example_2dof.png" caption="Figure 14: Two mass spring system" >}}

The modal masses can be easily found from the mode shape vectors:

\begin{align}
m\_1 &= \phi\_1^T M \phi\_1 = 50.8\,kg \\\\\\
m\_2 &= \phi\_2^T M \phi\_2 = 11.1\,kg
\end{align}

whereas the modal stiffnesses follow from \\(k\_i = \omega\_i^2 m\_i\\).

<a id="table--tab:2dof-example-modal-params"></a>
<div class="table-caption">
  <span class="table-number"><a href="#table--tab:2dof-example-modal-params">Table 1</a></span>:
  Modal results for the two mass spring system
</div>

|                   | Mode 1                        | Mode 2                          |
|-------------------|-------------------------------|---------------------------------|
| Frequency [Hz]    | \\(f\_1 = 47.8\\)             | \\(f\_2 = 167.7\\)              |
| Eigenvector [-]   | \\(\phi\_1^T = [0.67,0.74]\\) | \\(\phi\_2^T = [-0.11, 0.99]\\) |
| Modal Mass [kg]   | \\(m\_1 = 50.8\\)             | \\(m\_2 = 11.1\\)               |
| Modal Stiff [N/m] | \\(k\_1 = 0.46\cdot 10^7\\)   | \\(k\_2 = 1.23\cdot 10^7\\)     |

<a id="org9a6d0a0"></a>

{{< figure src="/ox-hugo/rankers98_example_2dof_modal.png" caption="Figure 15: Graphical representation of modes and modal parameters of the two mass spring system" >}}

From these results, the effective modal parameters for each mode, and for each individual DoF can be defined using equations \eqref{eq:m_modal_eff} and \eqref{eq:k_modal_eff}.
The results are summarized in Table [2](#table--tab:2dof-example-modal-params-eff).

<a id="table--tab:2dof-example-modal-params-eff"></a>
<div class="table-caption">
  <span class="table-number"><a href="#table--tab:2dof-example-modal-params-eff">Table 2</a></span>:
  Effective modal parameters for the two mass spring system
</div>

|                         | Mode 1                                          | Mode 2                                          |
|-------------------------|-------------------------------------------------|-------------------------------------------------|
| Effective mass - DoF 1  | \\(m\_{\text{eff},11} = 112.1\,kg\\)            | \\(m\_{\text{eff},21} = 927.9\,kg\\)            |
| Effective mass - DoF 2  | \\(m\_{\text{eff},12} = 92.8\,kg\\)             | \\(m\_{\text{eff},22} = 11.2\,kg\\)             |
| Effective stiff - DoF 1 | \\(k\_{\text{eff},11} = 1.02 \cdot 10^7\,N/m\\) | \\(k\_{\text{eff},21} = 1.02 \cdot 10^9\,N/m\\) |
| Effective stiff - DoF 2 | \\(k\_{\text{eff},12} = 0.84 \cdot 10^7\,N/m\\) | \\(k\_{\text{eff},22} = 1.25 \cdot 10^7\,N/m\\) |

The effective modal parameters can then be used in the graphical representation of Figure [16](#orgad02a5c).
Based on this representation, it is now very easy to construct the individual modal contributions to the frequency response function \\(x\_1/F\_1\\) of the example system (Figure [17](#org5c3b059)).

<a id="orgad02a5c"></a>

{{< figure src="/ox-hugo/rankers98_example_2dof_effective_modal.png" caption="Figure 16: Alternative graphical representation of modes of two mass spring system based on the effective modal mass and stiffnesses in DoF \\(x\_1\\)" >}}

One can observe that the low frequency part of each modal contribution corresponds to the inverse of the calculated effective modal mass stiffness at DoF \\(x\_1\\) whereas the high frequency contribution is defined by the effective modal mass.

In the final Bode diagram (Figure [17](#org5c3b059), below) one can observe an interference of the two modal contributions in the frequency range of the second natural frequency, which in this example leads to a combination of an anti-resonance an a resonance.

<a id="org5c3b059"></a>

{{< figure src="/ox-hugo/rankers98_2dof_example_frf.png" caption="Figure 17: Frequency Response Function \\(x\_1/f\_1\\)" >}}

</div>


### A Pragmatic View on Sensitivity Analysis {#a-pragmatic-view-on-sensitivity-analysis}

Sometimes it is required to change the dynamical properties of a system.
In such situation it is useful to known how to modify the system so as to bring about the desired change.
**Sensitivity analysis**, helps to determine the rate of change of each natural frequency with each of the system parameters.
It typical provides answers to questions such as:

-   Where should one reduce mass in order to achieve the most significant gain in natural frequency?
-   Between which two points of a structure should one add extra stiffness to increase the natural frequency?

The technique furthermore gives an indication of the amount of frequency shift that can be obtained.

<div class="exampl">
  <div></div>

Assuming that one is asked to increase the natural frequency of the mode corresponding to Figure [18](#org78df8fe) by attaching a linear spring \\(k\\) between two of the three represented DoF.
As the relative motion between \\(x\_A\\) and \\(x\_B\\) is the largest of all possible combinations, this is the choice that will maximize the natural frequency of the mode.

<a id="org78df8fe"></a>

{{< figure src="/ox-hugo/rankers98_example_3dof_sensitivity.png" caption="Figure 18: Graphical representation of a mod with 3 DoF" >}}

</div>

If one has to increase the frequency of a mode, one should focus on stiffening those components or connectors with the highest contribution to the modal **potential energy**.
On the other hand, components that contribute significantly to the modal **kinetic energy** are serious candidates for mass reduction.

A first-order approximation of the new natural frequency of mode i can easily be derived by considering the effective modal mass and stiffness of that mode in the relevant DoF.
In the case of an extra mass \\(\Delta m\\) in DoF \\(x\_k\\), the effective modal mass \\(m\_{\text{eff},i}\\) in that DoF is required, whereas in the case of an additional spring \\(\Delta k\\) between two DoF \\(x\_k\\) and \\(x\_l\\) one has to compare the contribution of \\(\Delta k\\) to the effective modal stiffness \\(k\_{\text{eff},i}\\) in the user DoF (\\(x\_k-x\_l\\)).
The new natural frequency of mode i will be approximately:

\begin{align}
f\_{\text{new},i}(\Delta m) &= \frac{1}{2\pi}\sqrt{\frac{k\_{\text{eff},i}}{m\_{\text{eff},i} + \Delta m}} = f\_{\text{old}} \sqrt{\frac{m\_{\text{eff},i}}{m\_{\text{eff},i} + \Delta m}} \label{eq:sensitivity\_add\_m} \\\\\\
f\_{\text{new},i}(\Delta k) &= \frac{1}{2\pi}\sqrt{\frac{k\_{\text{eff},i} + \Delta k}{m\_{\text{eff},i}}} = f\_{\text{old}} \sqrt{\frac{k\_{\text{eff},i} + \Delta k}{k\_{\text{eff},i}}} \label{eq:sensitivity\_add\_k}
\end{align}

<div class="exampl">
  <div></div>

Let's use the two mass spring system in Figure [14](#orgbf0f71b) as an example.

In order to analyze the effect of an extra mass at \\(x\_2\\), the effective modal mass at that DoF needs to be known for both modes (see Table [2](#table--tab:2dof-example-modal-params-eff)).
Then using equation \eqref{eq:sensitivity_add_m}, one can estimate the effect of an extra mass \\(\Delta m = 1\,kg\\) added to \\(m\_2\\).

To estimate the influence of extra stiffness between the two DoF, one needs to calculate the effective modal stiffness that corresponds to the relative motion between \\(x\_2\\) and \\(x\_1\\).
This can be graphically done as shown in Figure [19](#org4893595):

\begin{align}
k\_{\text{eff},1,(2-1)} &= 0.46 \cdot 10^7 / 0.07^2 = 93.9 \cdot 10^7 \, N/m \\\\\\
k\_{\text{eff},2,(2-1)} &= 1.23 \cdot 10^7 / 1.1^2 = 1.0 \cdot 10^7 \, N/m
\end{align}

And using equation \eqref{eq:sensitivity_add_m}, the effect of additional stiffness on the frequency of the two modes can be computed.

The results are summarized in Table [3](#table--tab:example-sensitivity-2dof-results).

<a id="table--tab:example-sensitivity-2dof-results"></a>
<div class="table-caption">
  <span class="table-number"><a href="#table--tab:example-sensitivity-2dof-results">Table 3</a></span>:
  Sensitivity analysis results
</div>

|                                                                     | f1 [Hz] | f2 [Hz] |
|---------------------------------------------------------------------|---------|---------|
| Original                                                            | 47.8    | 167.7   |
| \\(\Delta m = 1\,kg\\) added to \\(m\_2\\)                          | 47.5    | 160.7   |
| \\(\Delta k = 10^7\, N/m\\) added between \\(x\_2\\) and \\(x\_1\\) | 48.1    | 237.2   |

<a id="org4893595"></a>

{{< figure src="/ox-hugo/rankers98_example_sensitivity_2dof.png" caption="Figure 19: Graphical representation of modes and modal parameters of two mass spring system" >}}

</div>


### Modal Superposition {#modal-superposition}

Previously, the lever representation was used only to represent the individual mode shapes.
In the mechanism shown in Figure [20](#org3df11f4), the motion of the output \\(y\\) is equals to the sum of the motion of the two inputs \\(x\_1\\) and \\(x\_2\\).

<a id="org3df11f4"></a>

{{< figure src="/ox-hugo/rankers98_addition_of_motion.png" caption="Figure 20: Addition of motion" >}}

This approach can be applied to the concept of modal superposition, which expressed the motion of any physical DoF \\(x\_k(t)\\) as the summation of modal contribution:

\begin{equation}
x\_k(t) = \sum\_{i=1}^n \phi\_{ik} q\_i(t) = \sum\_{i=1}^n x\_{ki}(t)
\end{equation}

Combining the concept of summation of modal contribution with the lever representation of mode shapes leads to Figure [21](#orgb8f94d2), which is a visualization of the transformation between the modal and the physical domains.

<a id="orgb8f94d2"></a>

{{< figure src="/ox-hugo/rankers98_conversion_modal_to_physical.png" caption="Figure 21: Conversion between modal DoF to physical DoF" >}}


### Suspension Modes {#suspension-modes}

The "rigid body modes" usually refer to the lower natural frequencies of a machine that are caused by the flexibility of the suspension system.
This is misleading at it suggests that the structure exhibits no internal deformation.
A better term for such a mode would be **suspension mode**.

To illustrate the important of the internal deformation, a very simplified physical model of a precision machine is considered (Figure [22](#orgc5ca877)).

<a id="orgc5ca877"></a>

{{< figure src="/ox-hugo/rankers98_suspension_mode_machine.png" caption="Figure 22: Simplified physical model of a precision machine" >}}

The machine basically consists of a very heavy granite machine frame to which an optical unit is rigidly connected.
The optical unit takes images of a specimen that is mounted on a manipulator that has certain flexibility with respect to the granite machine frame.
For a proper operation of the machine, the internal deformation \\(\epsilon = x\_2 - x\_1\\) needs to be minimal.
Typically, such a machine is designed for high internal stiffness, and it is furthermore very softly supported in order to prevent external (floor) vibrations from entering the machine.

Assuming that the natural frequency \\(\omega\_1\\) of the suspension mode \\(\phi\_1\\) is significantly lower than that of the internal mode, one can approximate the frequency of the suspension mode by considering the motion of the entire machine as one rigid body on the stiffness of the suspension system.
However, one should keep in mind that there is always a small amount of internal deformation in case of a non-zero suspension stiffness \\(k\_{20}\\).
It can be shown than the internal deformation associated with the suspension mode is:

\begin{equation}
\epsilon = \frac{\omega\_1^2}{\omega\_{\text{int}}^2 x\_2}
\end{equation}

with \\(\omega\_{\text{int}} = \sqrt{\frac{k\_{12}}{m\_1}}\\) representing the natural frequency of the manipulator where the base frame is clamped or infinitely heavy.
This equation shows that the internal deformation associated with the suspension mode depends on the ratio of the natural frequencies of the internal mode compared to the suspension mode.

<div class="exampl">
  <div></div>

As an example of a situation in which the internal deformation associated with the suspension mode is of significant importance, one could consider a high precision machine that is excited due to floor vibrations such that it vibrates on its suspension with an amplitude of \\(100\, \mu m\\) and a frequency of 3 Hz.
Assuming that the internal frequency of the manipulator is equal to 150 Hz, the internal deformation of the machine is:

\begin{equation}
\epsilon = \frac{3^2}{150^2} 100 \, \mu m = 40\, nm
\end{equation}

which can be a lot for high precision machines.

</div>


## Modes and Servo Stability {#modes-and-servo-stability}

One of the two limiting effects


### Basic Characteristics of Mechanical FRF {#basic-characteristics-of-mechanical-frf}

Consider the position control loop of Figure [23](#org18af44d).

<a id="org18af44d"></a>

{{< figure src="/ox-hugo/rankers98_mechanical_servo_system.png" caption="Figure 23: Mechanical position servo-system" >}}

In the ideal situation the mechanical system behaves as one rigid body with mass \\(m\\), so the mechanical transfer function can be written as:

\begin{equation}
\frac{x\_{\text{servo}}}{F\_{\text{servo}}} = \frac{1}{m s^2}
\end{equation}

<a id="orgac4be89"></a>

{{< figure src="/ox-hugo/rankers98_ideal_bode_nyquist.png" caption="Figure 24: FRF of an ideal system with no resonances" >}}

In the case of one extra modal contribution, the equation for the mechanical transfer function needs to be extended with one extra term:

\begin{equation} \label{eq:effect\_one\_mode}
\frac{x\_{\text{servo}}}{F\_{\text{servo}}} = \frac{1}{m s^2} + \frac{\phi\_{i,\text{servo}} \phi\_{i,\text{force}}}{m\_i s^2 + k\_i} = \frac{1}{m s^2} + \frac{\phi\_{i,\text{servo}} \phi\_{i,\text{force}}}{m\_i s^2 + m\_i \omega\_i^2}
\end{equation}

The final transfer function and the exact interaction between the two parts depends on the values of the various parameters.

Let's introduce a variable \\(\alpha\\), which relates the high-frequency contribution of the mode to that of the rigid-body motion:

\begin{equation} \label{eq:alpha}
\alpha = \frac{\frac{\phi\_{i,\text{servo}} \phi\_{i,\text{force}}}{m\_i}}{\frac{1}{m}}
\end{equation}

which simplifies equation \eqref{eq:effect_one_mode} to:

\begin{equation}
\frac{x\_{\text{servo}}}{F\_{\text{servo}}} = \frac{1}{ms^2} + \frac{\alpha}{m s^2 + m \omega\_i^2}
\end{equation}

<a id="orgda4ef86"></a>

{{< figure src="/ox-hugo/rankers98_frf_effect_alpha.png" caption="Figure 25: Contribution of rigid-body motion and modal dynamics to the amplitude and phase of FRF for various values of \\(\alpha\\)" >}}

<a id="org6c0aa47"></a>

{{< figure src="/ox-hugo/rankers98_final_frf_alpha.png" caption="Figure 26: Bode diagram of final FRF (\\(x\_{\text{servo}}/F\_{\text{servo}}\\)) for six values of \\(\alpha\\)" >}}


#### FRF with "-2 slope/zero/pole/-2 slope" behavior {#frf-with-2-slope-zero-pole-2-slope-behavior}


#### FRF with "-2 slope/pole/zero/-2 slope" behavior {#frf-with-2-slope-pole-zero-2-slope-behavior}


#### FRF with "-2 slope/pole/-4 slope" behavior {#frf-with-2-slope-pole-4-slope-behavior}


#### FRF with "-2 slope/pole/-2 slope" behavior {#frf-with-2-slope-pole-2-slope-behavior}


#### Summary {#summary}

|           | << wb | ~ wb | >> wb |
|-----------|-------|------|-------|
| Pole Zero | OK    | NOK  | OK    |
| Zero Pole | NOK   | OK   | NOK   |
| Pole      | NOK   | NOK  | OK    |


### Destabilising Effect of Modes {#destabilising-effect-of-modes}


### Design for Stability {#design-for-stability}

<div class="important">
  <div></div>

Guiding system flexibility:

1.  Driving force at Center of Mass (Best practice)
2.  Locate sensor at Center of Mass (Second best)
3.  If none of the above can be achieved, one should aim at location sensors and driving force as close as possible to the Center of Mass.
    Furthermore, it is generally better if the location of the sensor and that of the driving force are at the same side of the Center of Mass.

</div>


## Predictive Modelling {#predictive-modelling}


### Steps in a Modelling Activity {#steps-in-a-modelling-activity}


### Step-wise Refined Modelling {#step-wise-refined-modelling}


### Practical Modelling Issues {#practical-modelling-issues}


## Conclusions {#conclusions}

<summary>
Machine dynamics, and the interaction with the control system, plays a dominant role in the performance of fast and accurate servo-controlled positioning devices such as compact disc, wafer-steppers, and component-mounters.

"Modal analysis" is a numerical and experimental tool that can be very profitable in understanding the nature of complicated mechanical resonances.
The mathematics of a single decoupled "modal" equation of motion can be translated into a graphical representation including all relevant data, which simplifies the understanding and creative use of the modal concept.
The introduction of the terms "effective" modal mass and stiffnesses enables a unique link between the modal and the physical domain.

From a servo stability point of view it is essential to investigate the mechanical FRF (\\(x/F\\)) which characterizes the dynamic properties of the mechanical system.
Once the dynamics of the one individual mode is fully understood it is straightforward to construct this FRF and the interaction between the desired rigid body motion and the contribution of one additional mode.
A closer investigation of this interaction reveals that only four interaction patterns exists.
The destabilizing effect of a mechanical resonance depends not only on the resulting typical interaction pattern in the FRF, but also on its frequency in relation to the intended bandwidth frequency of the control loop.
On the basis of these stability considerations, design guidelines for the mechanics of a servo positioning devices are derived, so as to minimize the effect of mechanical vibrations on the stability of the controlled system.

In view of its importance to the overall performance, the effect of machine dynamics should be monitored during the entire design process through the use of modelling and simulation techniques.
However, it is vital for the success of modelling and simulation as a tool to support design decisions, that analysis data are translated into useful information, and that this information is available on time.
This requires a proper balance between accuracy and speed that can best be achieved by a top-down analysis process, which is closely linked to the phases in the design process, and in which the simulation models are step-wise refined.

When many parts of the mechanical system need to be modelled in great detail it is not advisable to build one, single, huge FE model but rather to apply a so-called "sub-structuring" techniques.
The Craig-Bampton approach, which is a component mode technique based on a combination of all boundary constraint modes plus a limited number of fixed interface normal modes, was found to be favorable.
It has static solution capacity, and the frequency of the highest fixed-interface normal mode gives a good indication of the frequency range up to which the overall system results are valid.

Through the enormous performance drive in mechatronics systems, much has been learned in the past years about the influence of machine dynamics in servo positioning-devices.
</summary>



## Bibliography {#bibliography}

<a id="org6436602"></a>Rankers, Adrian Mathias. 1998. “Machine Dynamics in Mechatronic Systems: An Engineering Approach.” University of Twente.
